@@ -65,6 +65,18 @@ void Pattern::get_matrix(Matrix& matrix) const
   check_object_status_and_throw_exception(*this);
 }
 
+void Pattern::set_matrix(const cairo_matrix_t& matrix)
+{
+  cairo_pattern_set_matrix(m_cobject, (cairo_matrix_t*)&matrix);
+  check_object_status_and_throw_exception(*this);
+}
+
+void Pattern::get_matrix(cairo_matrix_t& matrix) const
+{
+  cairo_pattern_get_matrix(m_cobject, (cairo_matrix_t*)&matrix);
+  check_object_status_and_throw_exception(*this);
+}
+
 Matrix Pattern::get_matrix() const
 {
   Cairo::Matrix m;
